/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.component.sed;

import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.Exchange;
import org.apache.camel.impl.DefaultComponent;
import org.apache.camel.impl.ProcessorEndpoint;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.io.InputStream;
import java.util.Map;



/**
 * A Sed/Perl-like regular expression processing component for transforming messages
 *
 */
public class SedComponent extends DefaultComponent<Exchange> {

  private static final transient Log log = LogFactory.getLog( SedComponent.class );

  public SedComponent() {
  }

  public SedComponent(CamelContext context) {
    super(context);
  }

  protected Endpoint<Exchange> createEndpoint(String uri, String remaining, Map parameters)
    throws Exception {

    String inStreamName = remaining;

    //
    // Use the ProcessEndpoint helper class to generate a default endpoint 
    // from the Processor class
    //

    log.info("Creating endpoint from file/resource: " + inStreamName );
    
    InputStream inStream = getClass().getResourceAsStream( inStreamName );

    CamelContext camelContext = getCamelContext();
    
    /** @todo  This is currently throwing an exception - needs debugging */
    return new ProcessorEndpoint( uri, camelContext, 
                                  new SedProcessor( inStream ) );
  }
}



