/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.component.sed;


import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.util.regex.Pattern;


/**
 *  Class representing the parsed information for a single SED-like expression.
 *  i.e.:
 *
 *    's/version1.4/version1.3/g;'
 *
 *
 */
public class SedExpression {

  private static final transient Log log = LogFactory.getLog( SedExpression.class );

  String   _op;
  Pattern  _findPattern;
  String   _replacePattern;
  String   _options;
  boolean  _replaceAllFlag;

  public SedExpression( String op, Pattern findPattern, String replacePattern, String options )
  {
    _op = op;
    _findPattern = findPattern;
    _replacePattern = replacePattern;
    _options = options;

    //
    // If SED/Perl rule included a trailing 'g' option (global replace) set 
    // replaceAll flag
    //
    if( options != null )
      _replaceAllFlag = ( options.indexOf('g') >= 0 );
    else
      _replaceAllFlag = false;
  }
  
  public void setOp( String op ) {
    _op = op;
  }
  public String getOp() {
    return _op;
  }

  public void setFindPattern( Pattern findPattern ) {
    _findPattern = findPattern;
  }
  public Pattern getFindPattern() {
    return _findPattern;
  }

  public void setReplacePattern( String replacePattern ) {
    _replacePattern = replacePattern;
  }
  public String getReplacePattern() {
    return _replacePattern;
  }

  public boolean getReplaceAllFlag() {
    return _replaceAllFlag;
  }
  
}
